@@ -6,10 +6,9 @@ from importlib import import_module
 
 import sentry_sdk
 from sentry_sdk.consts import OP, SPANDATA
-from sentry_sdk.db.explain_plan.django import attach_explain_plan_to_span
 from sentry_sdk.scope import add_global_event_processor, should_send_default_pii
 from sentry_sdk.serializer import add_global_repr_processor
-from sentry_sdk.tracing import SOURCE_FOR_STYLE, TRANSACTION_SOURCE_URL
+from sentry_sdk.tracing import SOURCE_FOR_STYLE, TransactionSource
 from sentry_sdk.tracing_utils import add_query_source, record_sql_queries
 from sentry_sdk.utils import (
     AnnotatedValue,
@@ -23,10 +22,13 @@ from sentry_sdk.utils import (
     transaction_from_function,
     walk_exception_chain,
 )
-from sentry_sdk.integrations import Integration, DidNotEnable
+from sentry_sdk.integrations import _check_minimum_version, Integration, DidNotEnable
 from sentry_sdk.integrations.logging import ignore_logger
 from sentry_sdk.integrations.wsgi import SentryWsgiMiddleware
-from sentry_sdk.integrations._wsgi_common import RequestExtractor
+from sentry_sdk.integrations._wsgi_common import (
+    DEFAULT_HTTP_METHODS_TO_CAPTURE,
+    RequestExtractor,
+)
 
 try:
     from django import VERSION as DJANGO_VERSION
@@ -126,13 +128,14 @@ class DjangoIntegration(Integration):
 
     def __init__(
         self,
-        transaction_style="url",
-        middleware_spans=True,
-        signals_spans=True,
-        cache_spans=False,
-        signals_denylist=None,
+        transaction_style="url",  # type: str
+        middleware_spans=True,  # type: bool
+        signals_spans=True,  # type: bool
+        cache_spans=False,  # type: bool
+        signals_denylist=None,  # type: Optional[list[signals.Signal]]
+        http_methods_to_capture=DEFAULT_HTTP_METHODS_TO_CAPTURE,  # type: tuple[str, ...]
     ):
-        # type: (str, bool, bool, bool, Optional[list[signals.Signal]]) -> None
+        # type: (...) -> None
         if transaction_style not in TRANSACTION_STYLE_VALUES:
             raise ValueError(
                 "Invalid value for transaction_style: %s (must be in %s)"
@@ -146,12 +149,12 @@ class DjangoIntegration(Integration):
 
         self.cache_spans = cache_spans
 
+        self.http_methods_to_capture = tuple(map(str.upper, http_methods_to_capture))
+
     @staticmethod
     def setup_once():
         # type: () -> None
-
-        if DJANGO_VERSION < (1, 8):
-            raise DidNotEnable("Django 1.8 or newer is required.")
+        _check_minimum_version(DjangoIntegration, DJANGO_VERSION)
 
         install_sql_hook()
         # Patch in our custom middleware.
@@ -173,10 +176,17 @@ class DjangoIntegration(Integration):
 
             use_x_forwarded_for = settings.USE_X_FORWARDED_HOST
 
+            integration = sentry_sdk.get_client().get_integration(DjangoIntegration)
+
             middleware = SentryWsgiMiddleware(
                 bound_old_app,
                 use_x_forwarded_for,
                 span_origin=DjangoIntegration.origin,
+                http_methods_to_capture=(
+                    integration.http_methods_to_capture
+                    if integration
+                    else DEFAULT_HTTP_METHODS_TO_CAPTURE
+                ),
             )
             return middleware(environ, start_response)
 
@@ -388,7 +398,7 @@ def _set_transaction_name_and_source(scope, transaction_style, request):
 
         if transaction_name is None:
             transaction_name = request.path_info
-            source = TRANSACTION_SOURCE_URL
+            source = TransactionSource.URL
         else:
             source = SOURCE_FOR_STYLE[transaction_style]
 
@@ -412,10 +422,11 @@ def _set_transaction_name_and_source(scope, transaction_style, request):
         pass
 
 
-@ensure_integration_enabled(DjangoIntegration)
 def _before_get_response(request):
     # type: (WSGIRequest) -> None
     integration = sentry_sdk.get_client().get_integration(DjangoIntegration)
+    if integration is None:
+        return
 
     _patch_drf()
 
@@ -441,11 +452,10 @@ def _attempt_resolve_again(request, scope, transaction_style):
     _set_transaction_name_and_source(scope, transaction_style, request)
 
 
-@ensure_integration_enabled(DjangoIntegration)
 def _after_get_response(request):
     # type: (WSGIRequest) -> None
     integration = sentry_sdk.get_client().get_integration(DjangoIntegration)
-    if integration.transaction_style != "url":
+    if integration is None or integration.transaction_style != "url":
         return
 
     scope = sentry_sdk.get_current_scope()
@@ -492,13 +502,6 @@ def _make_wsgi_request_event_processor(weak_request, integration):
             # We have a `asgi_request_event_processor` for this.
             return event
 
-        try:
-            drf_request = request._sentry_drf_request_backref()
-            if drf_request is not None:
-                request = drf_request
-        except AttributeError:
-            pass
-
         with capture_internal_exceptions():
             DjangoRequestExtractor(request).extract_into_event(event)
 
@@ -511,11 +514,12 @@ def _make_wsgi_request_event_processor(weak_request, integration):
     return wsgi_request_event_processor
 
 
-@ensure_integration_enabled(DjangoIntegration)
 def _got_request_exception(request=None, **kwargs):
     # type: (WSGIRequest, **Any) -> None
     client = sentry_sdk.get_client()
     integration = client.get_integration(DjangoIntegration)
+    if integration is None:
+        return
 
     if request is not None and integration.transaction_style == "url":
         scope = sentry_sdk.get_current_scope()
@@ -530,6 +534,16 @@ def _got_request_exception(request=None, **kwargs):
 
 
 class DjangoRequestExtractor(RequestExtractor):
+    def __init__(self, request):
+        # type: (Union[WSGIRequest, ASGIRequest]) -> None
+        try:
+            drf_request = request._sentry_drf_request_backref()
+            if drf_request is not None:
+                request = drf_request
+        except AttributeError:
+            pass
+        self.request = request
+
     def env(self):
         # type: () -> Dict[str, str]
         return self.request.META
@@ -634,20 +648,6 @@ def install_sql_hook():
             span_origin=DjangoIntegration.origin_db,
         ) as span:
             _set_db_data(span, self)
-            options = (
-                sentry_sdk.get_client()
-                .options["_experiments"]
-                .get("attach_explain_plans")
-            )
-            if options is not None:
-                attach_explain_plan_to_span(
-                    span,
-                    self.cursor.connection,
-                    sql,
-                    params,
-                    self.mogrify,
-                    options,
-                )
             result = real_execute(self, sql, params)
 
         with capture_internal_exceptions():
@@ -683,7 +683,7 @@ def install_sql_hook():
 
         with sentry_sdk.start_span(
             op=OP.DB,
-            description="connect",
+            name="connect",
             origin=DjangoIntegration.origin_db,
         ) as span:
             _set_db_data(span, self)
@@ -715,8 +715,18 @@ def _set_db_data(span, cursor_or_db):
         connection_params = cursor_or_db.connection.get_dsn_parameters()
     else:
         try:
-            # psycopg3
-            connection_params = cursor_or_db.connection.info.get_parameters()
+            # psycopg3, only extract needed params as get_parameters
+            # can be slow because of the additional logic to filter out default
+            # values
+            connection_params = {
+                "dbname": cursor_or_db.connection.info.dbname,
+                "port": cursor_or_db.connection.info.port,
+            }
+            # PGhost returns host or base dir of UNIX socket as an absolute path
+            # starting with /, use it only when it contains host
+            pg_host = cursor_or_db.connection.info.host
+            if pg_host and not pg_host.startswith("/"):
+                connection_params["host"] = pg_host
         except Exception:
             connection_params = db.get_connection_params()
 
